@@ -80,7 +80,7 @@ class Act():
         valid = False
         while not valid and elapsed < timeout:
             try:
-                fullport = uwsgi_portsniffer.port_from_lsof(self.uwsgi_vassal)
+                fullport = uwsgi_portsniffer.port_from_lsof(self)
                 new_ip, new_port = fullport.split(':')
                 if new_port <> start_port:
                     self.uwsgi_ip = new_ip
@@ -88,7 +88,7 @@ class Act():
                     print 'OK %s:%s' % (new_ip,new_port)
                     valid = True
             except:
-                raise
+                pass
             if not valid:
                 time.sleep(nap)
                 elapsed = time.time() - starttime
